@@ -4,8 +4,7 @@
 
 #include <iostream>
 
-#include <argparse/argparse.hpp>
-
+#include <argparse/argparse_decl.hpp>
 #include "./catch-define.h"
 
 struct Coord
@@ -149,4 +148,4 @@ TEST_CASE("1. custom types", "[argument_parser]")
         REQUIRE(args3.try_get<std::vector<Coord> >("const_coord")->size() == 1);
 #endif  // C++17+
     }
-}
\ No newline at end of file
+}
